@@ -1,5 +1,5 @@
 """简介 Introduction:
-A simple text editor written in Python.
+A open-source text editor written in Python.
 It supports editing text files,binary files with various encodings
 which can be automatically detected.
 When you edit a binary file, the contents of the file are displayed as escape sequences.
@@ -39,14 +39,19 @@ except ImportError:windnd=None
 try:import chardet
 except ImportError:chardet=None
 
-__email__="3416445406@qq.com"
-__author__="七分诚意 qq:3076711200 邮箱:%s"%__email__
-__version__="1.3.2";__doc__=__doc__%__version__ # 在__doc__中加入版本信息
+__email__="3076711200@qq.com"
+__author__="qfcy qq:3076711200"
+__version__="1.3.4";__doc__=__doc__%__version__ # 在__doc__中加入版本信息
 
 def view_hex(byte):
     result=''
+    if hasattr(bytes,'hex'):
+        conv_hex = bytes.hex
+    else: # 低于Python 3.5(如3.4版), 没有bytes.hex内置方法
+        conv_hex = lambda b:hex(int.from_bytes(b,'big'))[2:]\
+                           .zfill(len(b)*2)
     for i in range(0,len(byte)):
-        result+= byte[i:i+1].hex().zfill(2) + ' '
+        result+= conv_hex(byte[i:i+1]).zfill(2) + ' '
         if (i+1) % 4 == 0:result+='\n'
     return result
 
@@ -138,11 +143,12 @@ class SearchDialog(Toplevel):
             except re.error as err:
                 handle(err,parent=self);return
         # 默认从当前光标位置开始查找
-        pos=text.search(key,INSERT,END,
+        pos=text.search(key,INSERT,'end-1c',# end-1c:忽略末尾换行符
                         regexp=self.use_regexpr.get(),
                         nocase=not self.match_case.get())
         if not pos:
-            pos=text.search(key,'1.0',END, # 尝试从开头循环查找
+            # 尝试从开头循环查找
+            pos=text.search(key,'1.0','end-1c',
                         regexp=self.use_regexpr.get(),
                         nocase=not self.match_case.get())
         if pos:
@@ -282,6 +288,7 @@ class Editor(Tk):
     FILETYPES=[("所有文件","*.*")]
     CONFIGFILE=os.getenv("userprofile")+"\\.pynotepad.pkl"
     AUTOWRAP=CHAR
+    SHOW_STATUS=True
 
     instances=[]
     def __init__(self,filename=""):
@@ -314,7 +321,8 @@ class Editor(Tk):
     def create_widgets(self):
         # 创建控件
         self.statusbar=Frame(self)
-        self.statusbar.pack(side=BOTTOM,fill=X)
+        if self.SHOW_STATUS:
+            self.statusbar.pack(side=BOTTOM,fill=X)
         self.status=Label(self.statusbar,justify=RIGHT)
         self.status.pack(side=RIGHT)
         self.txt_decoded=ScrolledText(self.statusbar,
@@ -436,6 +444,10 @@ class Editor(Tk):
         theme_menu.add_command(label="选择背景色",command=self.select_bg)
         theme_menu.add_command(label="重置",command=self.reset_theme)
         view.add_cascade(label="主题",menu=theme_menu)
+        self._show_status=IntVar(self)
+        self._show_status.set(1 if self.SHOW_STATUS else 0)
+        view.add_checkbutton(label="显示状态栏",command=self.show_statusbar,
+                         variable=self._show_status)
 
         helpmenu=Menu(self,tearoff=False)
         helpmenu.add_command(label="关于",command=self.about)
@@ -555,6 +567,15 @@ class Editor(Tk):
             if tag.lower() != "sel":
                 self.contents.tag_config(tag, background=self.contents["bg"])
 
+    def show_statusbar(self):
+        if self._show_status.get():
+            if self.isbinary:
+                self.statusbar.pack(side=BOTTOM,fill=X)
+            else:
+                self.statusbar.pack(side=BOTTOM,fill=X)
+        else:
+            self.statusbar.pack_forget()
+
 
     def window_onkey(self,event):
         # 如果按下Ctrl键
@@ -584,6 +605,7 @@ class Editor(Tk):
         self.file_modified=True
         self.update_status();self.change_title()
     def update_status(self,event=None):
+        if not self._show_status.get():return
         if self.isbinary:
             try:
                 selected=self.contents.get(SEL_FIRST,SEL_LAST)
@@ -675,7 +697,7 @@ class Editor(Tk):
                             initialdir=os.path.split(self.filename)[0],
                             filetypes=self.FILETYPES)
         if not filename:return
-        if not self.filename and not self.file_modified:
+        if not self.filename and not self.file_modified: # 如果是刚新建的, 在当前窗口中打开
             self.load(filename)
         else:self.new().load(filename)
     def open_as_binary(self):
@@ -684,7 +706,7 @@ class Editor(Tk):
                             initialdir=os.path.split(self.filename)[0],
                             filetypes=self.FILETYPES)
         if not filename:return
-        if not self.filename and not self.file_modified: # 如果是新建的
+        if not self.filename and not self.file_modified: # 如果是刚新建的
             self.load(filename,binary=True)
         else:self.new().load(filename,binary=True)
     def load(self,filename,binary=False):
@@ -829,9 +851,13 @@ class Editor(Tk):
             self.save()
 
     def about(self):
-        msgbox.showinfo("关于",__doc__+"\n作者: "+__author__,parent=self)
+        msgbox.showinfo("关于",__doc__,parent=self)
     def feedback(self):
-        webbrowser.open("https://blog.csdn.net/qfcy_/article/details/118399185")
+        msgbox.showinfo('PyNotepad',"""\
+PyNotepad提供了多个反馈渠道。
+若有反馈, 可以在 github.com/qfcy/Python 或 gitcode.net/qfcy_/Python 中创建issue。
+或者在作者 blog.csdn.net/qfcy_ 的文章 "python tkinter.Text 高级用法 -- 设计功能齐全的文本编辑器" 中填写评论。
+感谢您对PyNotepad项目的支持!""")
 
     def loadconfig(self):
         try:
@@ -851,14 +877,16 @@ class Editor(Tk):
              'NORMAL_FONTSIZE': int(font[-2]),
              'AUTOWRAP': self.contents['wrap'],
              'TEXT_BG':self.contents["bg"],
-             'TEXT_FG':self.contents["fg"],}
+             'TEXT_FG':self.contents["fg"],
+             "SHOW_STATUS":bool(self._show_status.get())}
         with open(self.CONFIGFILE,'wb') as f:
             pickle.dump(cfg,f)
     def onfiledrag(self,files):
         self.drag_files=files
         self.after(50,self.onfiledrag2)
     def onfiledrag2(self):
-        if not self.filename and not self.file_modified: # 如果是新建的
+        self.saveconfig()
+        if not self.filename and not self.file_modified: # 如果刚新建窗口
             self.load(self.drag_files[0].decode('ansi'))
             del self.drag_files[0]
         for item in self.drag_files:
